; $Id: fullchem_emissions.pro,v 1.5 2007/11/16 15:08:51 bmy Exp $ 
;-----------------------------------------------------------------------
;+
; NAME:
;        FULLCHEM_EMISSIONS
;
; PURPOSE:
;        Prints totals of GEOS-CHEM emission species for two different
;        model versions.  Also prints the difference in emission 
;        totals between the two model versions.
;
; CATEGORY:
;        GEOS-CHEM Benchmarking
;
; CALLING SEQUENCE:
;        FULLCHEM_EMISSIONS [ , Keywords ]
;
; INPUTS:
;        None
;
; KEYWORD PARAMETERS:
;        FILENEW -> Name of a binary punch file containing model
;             output from a "New" version of the GEOS-CHEM.   
;
;        FILEOLD -> Name of a binary punch file containing model
;             output from a "Old" version of the GEOS-CHEM. 
;
;        OUTFILENAME -> Name of the text file where emission totals
;             and differences will be sent.  Default is "emissions.txt".
;
; OUTPUTS:
;        None
;
; SUBROUTINES:
;        Internal Subroutines:
;        ==================================
;        GetVersionInfo (function)
;        WriteHeader
;        WriteTracers
;
;        External Subroutines Required:
;        ==================================
;        CTM_SUM_EMISSIONS 
;        UNDEFINE
; 
; REQUIREMENTS:
;        References routines from both GAMAP and TOOLS packages.
;
; NOTES:
;        (1) Assumes the version number is located at the end of
;            both FILENEW and FILEOLD
;
;        (2) Assumes that both FILENEW and FILEOLD contain the
;            following GEOS-CHEM diagnostic categories:
;            (a) ND11 ("ACETSRCE")   (e) ND34 ("BIOFSRCE")
;            (b) ND28 ("BIOBSRCE")   (f) ND36 ("ANTHSRCE")
;            (c) ND29 ("CO--SRCE")   (g) ND46 ("BIOGSRCE")
;            (d) ND32 ("NOX-AC-$", "NOX-AN-$", "NOX-BIOB", 
;                      "NOX-FERT", "NOX-LI-$", "NOX-SOIL")
;            (h) ND13 ("DMS-BIOG", "SO2-AC-$", "SO2-AN-$",
;                      "SO2-EV-$", "SO2-NV-$", "SO4-AN-$",
;                      "NH3-ANTH", "NH3-BIOB", "NH3-BIOG",
;                      "NH3-NATU", "SO2-SHIP")
;            (i) ND06 ( )
;            (j) ND07 ("DUSTSRCE")
;            (k) ND08 ("SALTSRCE")
;
; EXAMPLE:
;        FULLCHEM_EMISSIONS, FILENEW='ctm.bpch.v6-02-05', $
;                            FILEOLD='ctm.bpch.v6-02-04', $
;                            OUTFILENAME='emissions.txt'
;
;             ; Prints emissions & differences between 
;             ; versions 6-02-05 and 6-02-04
;                           
; MODIFICATION HISTORY:
;        bmy, 18 Jun 2001: VERSION 1.00
;        bmy, 20 Jun 2001: VERSION 1.01
;                          - now omit ALD2 (#11) from ANTHROPOGENIC
;        bmy, 20 Sep 2001: VERSION 1.02
;                          - now print ND11 acetone sources, sinks
;        bmy, 15 Aug 2002: VERSION 1.03
;                          - renamed to FULLCHEM_EMISSIONS
;                          - renamed FILE_NEW to FILENEW and 
;                            FILE_OLD to FILEOLD
;        bmy, 17 Jan 2003: VERSION 1.04
;                          - also sum up sulfate emission categories
;        bmy, 27 Mar 2003: VERSION 1.05
;                          - adjust FORMAT string for branch versions
;                          - now also print out NH3-NATU source
;        bmy, 09 Apr 2004: VERSION 1.06
;                          - Now print out emissions of BC/OC tracers
;                          - Now print out hydrophilic BC/OC which
;                            came from hydrophobic BC/OC
;        bmy, 28 Apr 2004: VERSION 1.07
;                          - Now print out dust emissions
;        bmy, 03 May 2004: VERSION 1.08
;                          - Now print out seasalt emissions
;        bmy, 21 May 2004: VERSION 1.09
;                          - Now print out ship exhaust SO2 emissions
;        bmy, 08 Jul 2005: VERSION 1.10
;                          - Updated for 43 tracers
;
;-
; Copyright (C) 2001-2005, Bob Yantosca, Harvard University
; This software is provided as is without any warranty
; whatsoever. It may be freely used, copied or distributed
; for non-commercial purposes. This copyright notice must be
; kept with any copy of this software. If this software shall
; be used commercially or sold as part of a larger package,
; please contact the author.
; Bugs and comments should be directed to bmy@io.harvard.edu
; with subject "IDL routine fullchem_emissions"
;-----------------------------------------------------------------------


function GetVersionInfo, FileName 
 
   ;====================================================================
   ; Internal subroutine GetVersionInfo extracts the GEOS-CHEM
   ; version string (e.g. v4-15) from an input file name.
   ;====================================================================   

   ; Look for the last period in the FILENAME string
   Ind = StrPos( FileName, '.', /Reverse_Search )
 
   ; Version string is between the last period and the end of the string
   if ( Ind[0] ge 0 ) then begin
      Version = StrMid( FileName, Ind[0]+1, StrLen( FileName )-Ind[0]+1 )
   endif else begin
      S = StrTrim( FileName ) + ' does not contain a version string!'
      Message, S 
   endelse
 
   ; Return the version string to the main program
   return, Version
 
end
 
;-----------------------------------------------------------------------------
 
pro WriteHeader, Ilun, Title, Version_New, Version_Old 

   ;====================================================================
   ; Internal subroutine WriteHeader writes a header for each emissions
   ; category with a top title and also the version string information.
   ;====================================================================  

   ; Get string lengths
   Lnew = StrLen( Version_New )
   Lold = StrLen( Version_Old )

   ; Pick FORMAT string based on the length of the version strings
   if ( Lnew gt 5 AND Lold gt 5 ) then begin
      Format = '('' Tracer  '',a8,3x,a8,3x,a8,'' - '',a8)'
   endif else if ( Lnew gt 5 AND Lold le 5 ) then begin
      Format = '('' Tracer   '',a8,5x,a5,4x,a8,'' - '',a5)'
   endif else if ( Lnew le 5 AND Lold gt 5 ) then begin
      Format = '('' Tracer    '',1x,a5,3x,a8,3x,a5,'' - '',a8)'
   endif else if ( Lnew le 5 AND Lold le 5 ) then begin
      Format = '('' Tracer    '',1x,a5,6x,a5,4x,a5,'' - '',a5)'
   endif

   PrintF, Ilun, Title
   PrintF, Ilun, Version_New, Version_Old, Version_New, Version_Old, $
                 Format=Format
   PrintF, Ilun, '====================================================='
 
   ; Return to main program
   return
end
 
;-----------------------------------------------------------------------------
 
pro WriteTracers, Ilun, New, Old, Advance=Advance

   ;====================================================================
   ; Internal subroutine WriteTracers writes tracer sums and
   ; differences for a given emissions category.
   ;====================================================================  

   ; Error check
   if ( N_Elements( New ) ne N_Elements( Old ) ) then begin
      Message, 'NEW and OLD do not have the same # of elements!'
   endif
 
   ; Write totals & difference to OUTFILENAME
   for N = 0L, N_Elements( New ) - 1L do begin
      PrintF, Ilun, New[N].Name, New[N].Sum, Old[N].Sum,  $
                    New[N].Sum - Old[N].Sum, New[N].Unit, $
                    Format='(a6,2(1x,f10.3),3x,f10.3,3x,a6)'
   endfor

   ; Write some spacers -- if /ADVANCE is set
   if ( Keyword_Set( Advance ) ) then begin
      PrintF, Ilun
      PrintF, Ilun
   endif

   ; Return to main program
   return
end
 
;-----------------------------------------------------------------------------
  
pro FullChem_Emissions, FileNew=FileNew,        $
                        FileOld=FileOld,        $
                        OutFileName=OutFileName

   ;====================================================================
   ; Initialization
   ;====================================================================
 
   ; Pass external functions
   FORWARD_FUNCTION GetVersionInfo

   ; Keyword settings
   if ( N_Elements( FileNew ) ne 1 ) then Message, 'FILENEW not passed!'
   if ( N_Elements( FileOld ) ne 1 ) then Message, 'FILEOLD not passed!'

   ; Get version information from input & output files
   Version_New = GetVersionInfo( FileNew )
   Version_Old = GetVersionInfo( FileOld )
 
   ; Default output file neame
   if ( N_Elements( OutFileName ) ne 1 ) $
      then OutFileName = Version_New + '.emissions.txt'
 
   ;====================================================================
   ; Print anthro totals from old & new versions
   ;====================================================================

   ; Open output file and get version strings from FILE_NEW and FILE_OLD
   Open_File, OutFileName, Ilun, /Write

   ; ==== Regular SMVGEAR tracers ====
   Tracer = [ 1, 4, 5, 9, 10, 18, 19, 21 ]
 
   CTM_Sum_Emissions, 'ANTHSRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'ANTHSRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
   
   WriteHeader,  Ilun, 'ANTHROPOGENIC', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Anthro SO2 ==== 
   Tracer = [ 26 ]

   CTM_Sum_Emissions, 'SO2-AN-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-AN-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Anthro SO4 ====
   Tracer = [ 27 ]
 
   CTM_Sum_Emissions, 'SO4-AN-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO4-AN-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Anthro NH3 ==== 
   Tracer = [ 30 ]

   CTM_Sum_Emissions, 'NH3-ANTH', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'NH3-ANTH', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old, /Advance

   ;====================================================================
   ; Print biomass burning totals from old & new versions
   ;====================================================================

   ; ==== Regular SMVGEAR Tracers ====
   Tracer = [ 1, 4, 5, 9, 10, 11, 18, 19, 20, 21 ]
 
   CTM_Sum_Emissions, 'BIOBSRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'BIOBSRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   WriteHeader,  Ilun, 'BIOMASS', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biomass SO2 ==== 
   Tracer = [ 26 ]

   CTM_Sum_Emissions, 'SO2-BIOB', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-BIOB', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biomass NH3 ==== 
   Tracer = [ 30 ]

   CTM_Sum_Emissions, 'NH3-BIOB', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'NH3-BIOB', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; Print biofuel burning totals from old & new versions
   ;==================================================================== 

   ; ==== Regular SMVGEAR Tracers ====
   Tracer = [ 1, 4, 5, 9, 10, 11, 18, 19, 20, 21 ]
   
   CTM_Sum_Emissions, 'BIOFSRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
   
   CTM_Sum_Emissions, 'BIOFSRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
   
   WriteHeader,  Ilun, 'BIOFUELS', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old

   UnDefine, New
   UnDefine, Old

   ; ==== Biofuel SO2 ==== 
   Tracer = [ 26 ]

   CTM_Sum_Emissions, 'SO2-BIOF', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-BIOF', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biofuel NH3 ==== 
   Tracer = [ 30 ]

   CTM_Sum_Emissions, 'NH3-BIOF', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'NH3-BIOF', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old
 
   ;====================================================================
   ; Print biogenic and natural totals from old & new versions
   ;==================================================================== 
   Tracer = [ 1, 2, 3, 4 ]
 
   CTM_Sum_Emissions, 'BIOGSRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'BIOGSRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   WriteHeader, Ilun, 'BIOGENIC AND NATURAL SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old

   UnDefine, New
   UnDefine, Old

   ; ==== Biogenic DMS ====
   Tracer = [ 25 ]
 
   CTM_Sum_Emissions, 'DMS-BIOG', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'DMS-BIOG', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old 

   ; ==== Natural Source NH3 ==== 
   Tracer = [ 30 ]
   
   CTM_Sum_Emissions, 'NH3-NATU', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'NH3-NATU', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; Print ACETONE sources from old & new versions
   ;==================================================================== 
   Tracer = [ 1, 2, 3, 4, 5, 6 ]
 
   CTM_Sum_Emissions, 'ACETSRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'ACETSRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   WriteHeader,  Ilun, 'ACETONE SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; Print ACETONE sinks from old & new versions
   ;==================================================================== 
   Tracer = [ 7 ]
 
   CTM_Sum_Emissions, 'ACETSRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'ACETSRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   WriteHeader,  Ilun, 'ACETONE SINKS', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; Print CO source totals from old & new versions
   ;==================================================================== 
   Tracer = [ 1, 2, 3, 4, 5 ]
 
   CTM_Sum_Emissions, 'CO--SRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'CO--SRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   WriteHeader,  Ilun, 'CO SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old
 
   ;====================================================================
   ; Print NOx source totals from old & new versions
   ;
   ; NOTE: NOx source (ND32) diagnostic saves different category
   ; names to the punch file, -- call CTM_SUM_EMISSIONS several times
   ;==================================================================== 
   Tracer = [ 1 ]
 
   ; ==== Aircraft NOx ====
   CTM_Sum_Emissions, 'NOX-AC-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'NOX-AC-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   New[0].Name = 'NOx-ac'
 
   WriteHeader,  Ilun, 'NOx SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old

   UnDefine, New
   UnDefine, Old
 
   ; ==== Anthro NOx ====
   CTM_Sum_Emissions, 'NOX-AN-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'NOX-AN-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   New[0].Name = 'NOx-an'
 
   WriteTracers, Ilun, New, Old

   UnDefine, New
   UnDefine, Old
 
   ; ==== Biomass NOx ====
   CTM_Sum_Emissions, 'NOX-BIOB', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'NOX-BIOB', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   New[0].Name = 'NOx-bb'
 
   WriteTracers, Ilun, New, Old

   UnDefine, New
   UnDefine, Old

    ; ==== Biofuels NOx ====
   CTM_Sum_Emissions, 'NOX-BIOF', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'NOX-BIOF', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   New[0].Name = 'NOx-bf'
 
   WriteTracers, Ilun, New, Old

   UnDefine, New
   UnDefine, Old
 
   ; ==== Fertilizer NOx ====
   CTM_Sum_Emissions, 'NOX-FERT', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'NOX-FERT', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   New[0].Name = 'NOx-fe'
 
   WriteTracers, Ilun, New, Old

   UnDefine, New
   UnDefine, Old
   
   ; ==== Lightning NOx ====
   CTM_Sum_Emissions, 'NOX-LI-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'NOX-LI-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   New[0].Name = 'NOx-li'
 
   WriteTracers, Ilun, New, Old

   UnDefine, New
   UnDefine, Old
 
   ; ==== Soil NOx ====
   CTM_Sum_Emissions, 'NOX-SOIL', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New
 
   CTM_Sum_Emissions, 'NOX-SOIL', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old
 
   New[0].Name = 'NOx-so'
 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; DMS emissions
   ;====================================================================
   Tracer = [ 25 ]
 
   CTM_Sum_Emissions, 'DMS-BIOG', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'DMS-BIOG', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'DMS-bg'

   WriteHeader,  Ilun, 'DMS SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; SO2 emissions
   ;====================================================================
   Tracer = [ 26 ]

   ; ==== Aircraft SO2 ==== 
   CTM_Sum_Emissions, 'SO2-AC-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-AC-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'SO2-ac'

   WriteHeader,  Ilun, 'SO2 SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Anthro SO2 ==== 
   CTM_Sum_Emissions, 'SO2-AN-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-AN-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'SO2-an'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biomass SO2 ==== 
   CTM_Sum_Emissions, 'SO2-BIOB', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-BIOB', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'SO2-bb'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biofuel SO2 ==== 
   CTM_Sum_Emissions, 'SO2-BIOF', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-BIOF', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'SO2-bf'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Non-Eruptive Volcano SO2 ==== 
   CTM_Sum_Emissions, 'SO2-NV-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-NV-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'SO2-nv'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Eruptive Volcano SO2 ==== 
   CTM_Sum_Emissions, 'SO2-EV-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-EV-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'SO2-ev'

   WriteTracers, Ilun, New, Old
 
   ; ==== Ship exhaust SO2 ==== 
   CTM_Sum_Emissions, 'SO2-SHIP', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO2-SHIP', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'SO2-sh'

   WriteTracers, Ilun, New, Old, /Advance

   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; SO4 emissions
   ;====================================================================
   Tracer = [ 27 ]
 
   CTM_Sum_Emissions, 'SO4-AN-$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'SO4-AN-$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'SO4-an'

   WriteHeader,  Ilun, 'SO4 SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; NH3 emissions
   ;====================================================================
   Tracer = [ 30 ]

   ; ==== Anthro NH3 ==== 
   CTM_Sum_Emissions, 'NH3-ANTH', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'NH3-ANTH', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'NH3-an'

   WriteHeader,  Ilun, 'NH3 SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biomass NH3 ==== 
   CTM_Sum_Emissions, 'NH3-BIOB', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'NH3-BIOB', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'NH3-bb'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biofuel NH3 ==== 
   CTM_Sum_Emissions, 'NH3-BIOF', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'NH3-BIOF', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'NH3-bf'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Natural Source NH3 ==== 
   CTM_Sum_Emissions, 'NH3-NATU', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'NH3-NATU', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'NH3-na'

   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; BLACK CARBON emissions (sum of Hydrophilic and Hydrophobic)
   ;====================================================================

   Tracer = [ 34 ]

   ; ==== Anthro BLKC ==== 
   CTM_Sum_Emissions, 'BC-ANTH', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'BC-ANTH', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg

   New[0].Name = 'BC-an'

   WriteHeader,  Ilun, 'BLACK CARBON SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biomass BLKC ==== 
   CTM_Sum_Emissions, 'BC-BIOB', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'BC-BIOB', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'BC-bb'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biofuel BLKC ==== 
   CTM_Sum_Emissions, 'BC-BIOF', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'BC-BIOF', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'BC-bf'

   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; ORGANIC CARBON emissions (both Hydrophilic and Hydrophobic)
   ;====================================================================
 
   Tracer = [ 35 ]

   ; ==== Anthro ORGC ==== 
   CTM_Sum_Emissions, 'OC-ANTH', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'OC-ANTH', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg

   New[0].Name = 'OC-an'

   WriteHeader,  Ilun, 'ORGANIC CARBON SOURCES', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biomass ORGC ==== 
   CTM_Sum_Emissions, 'OC-BIOB', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'OC-BIOB', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg

   New[0].Name = 'OC-bb'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old


   ; ==== Biofuel ORGC ==== 
   CTM_Sum_Emissions, 'OC-BIOF', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'OC-BIOF', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'OC-bf'

   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Biogenic ORGC ==== 
   CTM_Sum_Emissions, 'OC-BIOG', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'OC-BIOG', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'OC-bg'

   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; Hydrophilic from hydrophobic tracer
   ;====================================================================

   Tracer = [ 34 ]

   ; ==== Converted BLKC ==== 
   CTM_Sum_Emissions, 'PL-BC=$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'PL-BC=$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg

   New[0].Name = 'BC-hp'

   WriteHeader,  Ilun, 'HYDROPHILIC TRACER FROM HYDROPHOBIC TRACER', $
                 Version_New, Version_Old 
   WriteTracers, Ilun, New, Old
 
   UnDefine, New
   UnDefine, Old

   ; ==== Converted ORGC  ==== 
   Tracer = [ 35 ]

   CTM_Sum_Emissions, 'PL-OC=$', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /No_Sec, /Kg
 
   CTM_Sum_Emissions, 'PL-OC=$', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /No_Sec, /Kg
 
   New[0].Name = 'OC-hp'

   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; DUST emissions
   ;====================================================================

   ; ==== Dust tracers ====
   Tracer = [ 38, 39, 40, 41 ]
 
   CTM_Sum_Emissions, 'DUSTSRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /Kg, /No_Sec
 
   CTM_Sum_Emissions, 'DUSTSRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /Kg, /No_Sec
 
   WriteHeader,  Ilun, 'DUST EMISSIONS', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; SEASALT emissions
   ;====================================================================

   ; ==== Seasalt tracers ====
   Tracer = [ 42, 43 ]
 
   CTM_Sum_Emissions, 'SALTSRCE', $
      File=FileNew, Tracer=Tracer, /Cum_Only, Result=New, /Kg, /No_Sec
 
   CTM_Sum_Emissions, 'SALTSRCE', $
      File=FileOld, Tracer=Tracer, /Cum_Only, Result=Old, /Kg, /No_Sec
 
   WriteHeader,  Ilun, 'SEA SALT EMISSIONS', Version_New, Version_Old 
   WriteTracers, Ilun, New, Old, /Advance
 
   UnDefine, New
   UnDefine, Old

   ;====================================================================
   ; Close file and quit
   ;====================================================================
quit:
   Close,    Ilun
   Free_LUN, Ilun
 
   return
end
   
   
 
 
   
